import * as i0 from '@angular/core';
import { Injectable, InjectionToken, APP_INITIALIZER, NgModule } from '@angular/core';
import { TranslateLoader } from '@ngx-translate/core';
import { BehaviorSubject } from 'rxjs';
import { skipWhile, map } from 'rxjs/operators';

function generatePathMap(obj, basePath = '') {
    return Object.keys(obj).reduce((result, key) => {
        const path = basePath === '' ? key : `${basePath}.${key}`;
        if (typeof obj[key] === 'object') {
            result[key] = generatePathMap(obj[key], path);
        }
        else {
            result[key] = path;
        }
        return result;
    }, {});
}
class StaticTypescriptTranslateService extends TranslateLoader {
    constructor() {
        super();
        this.langObjects$ = new BehaviorSubject(undefined);
        this.langObjects = {};
    }
    getTranslation(lang) {
        return this.langObjects$.pipe(skipWhile(value => value === undefined), map(langObjects => {
            let langObject = langObjects[lang];
            if (langObject === undefined) {
                langObject = {};
            }
            return langObject;
        }));
    }
    getPathMap() {
        return this.pathMap;
    }
    addLangs(configs) {
        configs.forEach(config => {
            const innerConfig = config;
            this.addLangsFromConfig(innerConfig[0]);
        });
        this.langObjects$.next(this.langObjects);
        this.setPathMap();
    }
    setPathMap() {
        // const key = Object.keys(this.langObjects)[0]
        // this.pathMap = generatePathMap(this.langObjects[key])
        // console.log('bbq pathMap', this.pathMap)
    }
    addLangsFromConfig(config) {
        Object.keys(config.langs).forEach(lang => {
            const object = this.getOrCreateLangObject(lang);
            if (config.prefix === undefined) {
                this.addAllLangKeys(config, lang, object);
            }
            else {
                object[config.prefix] = config.langs[lang][config.prefix];
            }
            this.langObjects[lang] = object;
        });
    }
    addAllLangKeys(config, lang, object) {
        const configLang = config.langs[lang];
        Object.keys(configLang).forEach(key => {
            object[key] = configLang[key];
        });
    }
    getOrCreateLangObject(lang) {
        let object = this.langObjects[lang];
        if (object === undefined) {
            object = {};
        }
        return object;
    }
}
StaticTypescriptTranslateService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
StaticTypescriptTranslateService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

const LANG_TOKEN = new InjectionToken('LANG_TOKEN');
function addChildConfig(service, config) {
    return () => {
        service.addLangs(config);
    };
}
class StaticTypescriptTranslateModule {
    static forRoot(langs) {
        const config = {
            langs, prefix: undefined
        };
        return {
            ngModule: StaticTypescriptTranslateModule,
            providers: [
                StaticTypescriptTranslateService,
                {
                    provide: LANG_TOKEN,
                    multi: true,
                    useValue: [config]
                },
                {
                    provide: APP_INITIALIZER, multi: true,
                    useFactory: addChildConfig, deps: [StaticTypescriptTranslateService, LANG_TOKEN]
                }
            ]
        };
    }
    static forChild(config) {
        return {
            ngModule: StaticTypescriptTranslateModule,
            providers: [
                {
                    provide: LANG_TOKEN,
                    multi: true,
                    useValue: [config]
                }
            ]
        };
    }
}
StaticTypescriptTranslateModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
StaticTypescriptTranslateModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateModule });
StaticTypescriptTranslateModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.7", ngImport: i0, type: StaticTypescriptTranslateModule, decorators: [{
            type: NgModule,
            args: [{}]
        }] });

/*
 * Public API Surface of static-typescript-translate
 */

/**
 * Generated bundle index. Do not edit.
 */

export { LANG_TOKEN, StaticTypescriptTranslateModule, StaticTypescriptTranslateService, generatePathMap };
//# sourceMappingURL=gorlug-static-typescript-translate.mjs.map
